import { __decorate, __param } from 'tslib';
import { EventEmitter, VERSION, Renderer2, ElementRef, Inject, PLATFORM_ID, Output, Input, Component, NgModule } from '@angular/core';
import uploadcare from 'uploadcare-widget';
import { isPlatformBrowser } from '@angular/common';

const APP_VERSION = '2.0.0';

/* tslint:disable:no-output-rename no-input-rename no-output-on-prefix variable-name */
let UcWidgetComponent = class UcWidgetComponent {
    constructor(renderer, element, platformId) {
        this.onUploadComplete = new EventEmitter();
        this.onChange = new EventEmitter();
        this.onProgress = new EventEmitter();
        this._publicKey = 'demopublickey';
        this._value = null;
        this._cdnBase = null;
        this._reinitRequired = false;
        this._isClearValue = false;
        this._validators = [];
        this.element = element;
        this.renderer = renderer;
        this.isInBrowser = isPlatformBrowser(platformId);
        if (this.isInBrowser) {
            uploadcare.start({ integration: `Angular/${VERSION.full}; Ngx-Uploadcare-Widget/${APP_VERSION}` });
        }
    }
    set publicKey(publicKey) {
        this._publicKey = publicKey;
        this.setReinitFlag(true);
    }
    get publicKey() { return this._publicKey; }
    set multiple(multiple) {
        this._multiple = multiple;
        this.setReinitFlag(true);
    }
    get multiple() { return this._multiple; }
    set multipleMax(multipleMax) {
        this._multipleMax = multipleMax;
        this.setReinitFlag(false);
    }
    get multipleMax() { return this._multipleMax; }
    set multipleMin(multipleMin) {
        this._multipleMin = multipleMin;
        this.setReinitFlag(false);
    }
    get multipleMin() { return this._multipleMin; }
    set imagesOnly(imagesOnly) {
        this._imagesOnly = imagesOnly;
        this.setReinitFlag(false);
    }
    get imagesOnly() { return this._imagesOnly; }
    set previewStep(previewStep) {
        this._previewStep = previewStep;
        this.setReinitFlag(false);
    }
    get previewStep() { return this._previewStep; }
    set crop(crop) {
        this._crop = crop;
        this.setReinitFlag(false);
    }
    get crop() { return this._crop; }
    set imageShrink(imageShrink) {
        this._imageShrink = imageShrink;
        this.setReinitFlag(false);
    }
    get imageShrink() { return this._imageShrink; }
    set clearable(clearable) {
        this._clearable = clearable;
        this.setReinitFlag(false);
    }
    get clearable() { return this._clearable; }
    set tabs(tabs) {
        this._tabs = tabs;
        this.setReinitFlag(false);
    }
    get tabs() { return this._tabs; }
    set inputAcceptTypes(inputAcceptTypes) {
        this._inputAcceptTypes = inputAcceptTypes;
        this.setReinitFlag(false);
    }
    get inputAcceptTypes() { return this._inputAcceptTypes; }
    set preferredTypes(preferredTypes) {
        this._preferredTypes = preferredTypes;
        this.setReinitFlag(false);
    }
    get preferredTypes() { return this._preferredTypes; }
    set systemDialog(systemDialog) {
        this._systemDialog = systemDialog;
        this.setReinitFlag(false);
    }
    get systemDialog() { return this._systemDialog; }
    set secureSignature(secureSignature) {
        this._secureSignature = secureSignature;
        this.setReinitFlag(true);
    }
    get secureSignature() { return this._secureSignature; }
    set secureExpire(secureExpire) {
        this._secureExpire = secureExpire;
        this.setReinitFlag(false);
    }
    get secureExpire() { return this._secureExpire; }
    set value(value) {
        this._value = value;
        if (this.widget) {
            this.setReinitFlag(false);
            this.widget.value(value);
        }
    }
    get value() { return this._value; }
    set validators(validatorsArr) {
        this._validators = validatorsArr;
        this.setReinitFlag(false);
    }
    get validators() { return this._validators; }
    set cdnBase(cdnBase) {
        this._cdnBase = cdnBase;
        this.setReinitFlag(true);
    }
    get cdnBase() { return this._cdnBase; }
    set doNotStore(doNotStore) {
        this._doNotStore = doNotStore;
        this.setReinitFlag(false);
    }
    get doNotStore() { return this._doNotStore; }
    ngAfterViewInit() {
        if (this.isInBrowser) {
            this.widget = this.init();
        }
    }
    ngAfterViewChecked() {
        if (this._reinitRequired) {
            this.reset(this._isClearValue);
        }
    }
    reset(clearUploads = false) {
        this.destroy();
        this.widget = this.init(clearUploads);
        this._reinitRequired = false;
        this._isClearValue = false;
    }
    clearUploads() {
        this._value = null;
        if (this.widget) {
            this.widget.value(null);
        }
    }
    openDialog() {
        if (this.widget) {
            this.dialog = this.widget.openDialog();
        }
    }
    reject() {
        if (this.dialog) {
            this.dialog.reject();
            this.dialog = null;
        }
    }
    setReinitFlag(isClearValue) {
        if (this.widget) {
            this._reinitRequired = true;
            this._isClearValue = isClearValue;
        }
    }
    setInputAttr(key, value) {
        if (value) {
            this.renderer.setAttribute(this.inputElement, key, value);
        }
    }
    initInputElement() {
        this.setInputAttr('type', 'hidden');
        this.setInputAttr('data-public-key', this._publicKey);
        this.setInputAttr('data-multiple', this._multiple);
        this.setInputAttr('data-multiple-max', this._multipleMax);
        this.setInputAttr('data-multiple-min', this._multipleMin);
        this.setInputAttr('data-images-only', this._imagesOnly);
        this.setInputAttr('data-preview-step', this._previewStep);
        this.setInputAttr('data-crop', this._crop);
        this.setInputAttr('data-image-shrink', this._imageShrink);
        this.setInputAttr('data-clearable', this._clearable);
        this.setInputAttr('data-tabs', this._tabs);
        this.setInputAttr('data-input-accept-types', this._inputAcceptTypes);
        this.setInputAttr('data-preferred-types', this._preferredTypes);
        this.setInputAttr('data-system-dialog', this._systemDialog);
        this.setInputAttr('data-secure-signature', this._secureSignature);
        this.setInputAttr('data-secure-expire', this._secureExpire);
        this.setInputAttr('data-cdn-base', this._cdnBase);
        this.setInputAttr('data-do-not-store', this._doNotStore);
        if (this._value) {
            this.renderer.setProperty(this.inputElement, 'value', this._value);
        }
    }
    init(removeUploads = false) {
        this.inputElement = this.renderer.createElement('input');
        this.renderer.appendChild(this.element.nativeElement, this.inputElement);
        if (removeUploads) {
            this.clearUploads();
        }
        this.initInputElement();
        const widget = uploadcare.Widget(this.inputElement);
        this._validators.forEach(v => {
            if (typeof v === 'function') {
                widget.validators.push(v);
            }
            else {
                throw new Error('Only functions allowed in validadators array');
            }
        });
        widget.onUploadComplete((fileInfo) => {
            this.onUploadComplete.emit(fileInfo);
            this._value = fileInfo.uuid;
        });
        widget.onChange((selectionPromise) => {
            this.onChange.emit(selectionPromise);
            if (!selectionPromise) {
                return;
            }
            if (typeof selectionPromise.promise === 'function') {
                selectionPromise.promise()
                    .progress((progress) => {
                    this.onProgress.emit(progress);
                });
            }
            else {
                selectionPromise
                    .progress((progress) => {
                    this.onProgress.emit(progress);
                });
            }
        });
        widget.onDialogOpen((dialogApi) => {
            this.dialog = dialogApi;
        });
        return widget;
    }
    destroy() {
        const $ = uploadcare.jQuery;
        $(this.widget.inputElement.nextSibling).remove();
        $(this.widget.inputElement).clone().appendTo($(this.element.nativeElement));
        $(this.widget.inputElement).remove();
        this.renderer.removeChild(this.element.nativeElement, this.element.nativeElement.children[0]);
        delete this.widget;
    }
};
UcWidgetComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef },
    { type: String, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] }
];
__decorate([
    Output('on-upload-complete')
], UcWidgetComponent.prototype, "onUploadComplete", void 0);
__decorate([
    Output('on-change')
], UcWidgetComponent.prototype, "onChange", void 0);
__decorate([
    Output('on-progress')
], UcWidgetComponent.prototype, "onProgress", void 0);
__decorate([
    Input('public-key')
], UcWidgetComponent.prototype, "publicKey", null);
__decorate([
    Input('multiple')
], UcWidgetComponent.prototype, "multiple", null);
__decorate([
    Input('multiple-max')
], UcWidgetComponent.prototype, "multipleMax", null);
__decorate([
    Input('multiple-min')
], UcWidgetComponent.prototype, "multipleMin", null);
__decorate([
    Input('images-only')
], UcWidgetComponent.prototype, "imagesOnly", null);
__decorate([
    Input('preview-step')
], UcWidgetComponent.prototype, "previewStep", null);
__decorate([
    Input('crop')
], UcWidgetComponent.prototype, "crop", null);
__decorate([
    Input('image-shrink')
], UcWidgetComponent.prototype, "imageShrink", null);
__decorate([
    Input('clearable')
], UcWidgetComponent.prototype, "clearable", null);
__decorate([
    Input('tabs')
], UcWidgetComponent.prototype, "tabs", null);
__decorate([
    Input('input-accept-types')
], UcWidgetComponent.prototype, "inputAcceptTypes", null);
__decorate([
    Input('preferred-types')
], UcWidgetComponent.prototype, "preferredTypes", null);
__decorate([
    Input('system-dialog')
], UcWidgetComponent.prototype, "systemDialog", null);
__decorate([
    Input('secure-signature')
], UcWidgetComponent.prototype, "secureSignature", null);
__decorate([
    Input('secure-expire')
], UcWidgetComponent.prototype, "secureExpire", null);
__decorate([
    Input('value')
], UcWidgetComponent.prototype, "value", null);
__decorate([
    Input('validators')
], UcWidgetComponent.prototype, "validators", null);
__decorate([
    Input('cdn-base')
], UcWidgetComponent.prototype, "cdnBase", null);
__decorate([
    Input('do-not-store')
], UcWidgetComponent.prototype, "doNotStore", null);
UcWidgetComponent = __decorate([
    Component({
        selector: 'ngx-uploadcare-widget',
        template: ''
    }),
    __param(2, Inject(PLATFORM_ID))
], UcWidgetComponent);

/* tslint:disable:no-output-rename no-input-rename no-output-on-prefix */
let UcWidgetCustomComponent = class UcWidgetCustomComponent {
    constructor(platformId) {
        this.onUploadComplete = new EventEmitter();
        this.onChange = new EventEmitter();
        this.onProgress = new EventEmitter();
        this.publicKey = 'demopublickey';
        this.validators = [];
        const isInBrowser = isPlatformBrowser(platformId);
        if (isInBrowser) {
            uploadcare.start({ integration: `Angular/${VERSION.full}; Ngx-Uploadcare-Widget/${APP_VERSION}` });
        }
    }
    openDialog() {
        const config = {
            publicKey: this.publicKey ? this.publicKey : undefined,
            multiple: this.multiple,
            multipleMax: this.multipleMax,
            multipleMin: this.multipleMin,
            imagesOnly: this.imagesOnly,
            previewStep: this.previewStep,
            crop: this.crop ? this.crop : undefined,
            imageShrink: this.imageShrink ? this.imageShrink : undefined,
            clearable: this.clearable,
            tabs: this.tabs ? this.tabs : undefined,
            inputAcceptTypes: this.inputAcceptTypes ? this.inputAcceptTypes : undefined,
            preferredTypes: this.preferredTypes,
            systemDialog: this.systemDialog,
            secureSignature: this.secureSignature,
            secureExpire: this.secureExpire,
            value: this.value ? this.value : undefined,
            cdnBase: this.cdnBase ? this.cdnBase : undefined,
            doNotStore: this.doNotStore,
            validators: this.validators.filter(v => {
                if (typeof v !== 'function') {
                    throw new Error('Only functions allowed in validadators array');
                }
                return v;
            }),
        };
        this.dialog = uploadcare.openDialog(this.value, null, config);
        this.dialog.done((selectionPromise) => {
            this.onChange.emit(selectionPromise);
            if (typeof selectionPromise.promise === 'function') {
                selectionPromise.promise()
                    .then((groupInfo) => {
                    this.onUploadComplete.emit(groupInfo);
                })
                    .progress((progress) => {
                    this.onProgress.emit(progress);
                });
            }
            else {
                selectionPromise
                    .then((fileInfo) => {
                    this.onUploadComplete.emit(fileInfo);
                })
                    .progress((progress) => {
                    this.onProgress.emit(progress);
                });
            }
        });
    }
    reject() {
        if (this.dialog) {
            this.dialog.reject();
            this.dialog = null;
        }
    }
};
UcWidgetCustomComponent.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] }
];
__decorate([
    Output('on-upload-complete')
], UcWidgetCustomComponent.prototype, "onUploadComplete", void 0);
__decorate([
    Output('on-change')
], UcWidgetCustomComponent.prototype, "onChange", void 0);
__decorate([
    Output('on-progress')
], UcWidgetCustomComponent.prototype, "onProgress", void 0);
__decorate([
    Input('public-key')
], UcWidgetCustomComponent.prototype, "publicKey", void 0);
__decorate([
    Input('multiple')
], UcWidgetCustomComponent.prototype, "multiple", void 0);
__decorate([
    Input('multiple-max')
], UcWidgetCustomComponent.prototype, "multipleMax", void 0);
__decorate([
    Input('multiple-min')
], UcWidgetCustomComponent.prototype, "multipleMin", void 0);
__decorate([
    Input('images-only')
], UcWidgetCustomComponent.prototype, "imagesOnly", void 0);
__decorate([
    Input('preview-step')
], UcWidgetCustomComponent.prototype, "previewStep", void 0);
__decorate([
    Input('crop')
], UcWidgetCustomComponent.prototype, "crop", void 0);
__decorate([
    Input('image-shrink')
], UcWidgetCustomComponent.prototype, "imageShrink", void 0);
__decorate([
    Input('clearable')
], UcWidgetCustomComponent.prototype, "clearable", void 0);
__decorate([
    Input('tabs')
], UcWidgetCustomComponent.prototype, "tabs", void 0);
__decorate([
    Input('input-accept-types')
], UcWidgetCustomComponent.prototype, "inputAcceptTypes", void 0);
__decorate([
    Input('preferred-types')
], UcWidgetCustomComponent.prototype, "preferredTypes", void 0);
__decorate([
    Input('system-dialog')
], UcWidgetCustomComponent.prototype, "systemDialog", void 0);
__decorate([
    Input('secure-signature')
], UcWidgetCustomComponent.prototype, "secureSignature", void 0);
__decorate([
    Input('secure-expire')
], UcWidgetCustomComponent.prototype, "secureExpire", void 0);
__decorate([
    Input('value')
], UcWidgetCustomComponent.prototype, "value", void 0);
__decorate([
    Input('cdn-base')
], UcWidgetCustomComponent.prototype, "cdnBase", void 0);
__decorate([
    Input('do-not-store')
], UcWidgetCustomComponent.prototype, "doNotStore", void 0);
__decorate([
    Input('validators')
], UcWidgetCustomComponent.prototype, "validators", void 0);
UcWidgetCustomComponent = __decorate([
    Component({
        selector: 'ngx-uploadcare-widget-custom',
        template: ''
    }),
    __param(0, Inject(PLATFORM_ID))
], UcWidgetCustomComponent);

let UcWidgetModule = class UcWidgetModule {
};
UcWidgetModule = __decorate([
    NgModule({
        declarations: [
            UcWidgetCustomComponent,
            UcWidgetComponent
        ],
        imports: [],
        providers: [],
        bootstrap: [],
        exports: [
            UcWidgetCustomComponent,
            UcWidgetComponent
        ],
    })
], UcWidgetModule);

/**
 * Generated bundle index. Do not edit.
 */

export { UcWidgetComponent, UcWidgetCustomComponent, UcWidgetModule };
//# sourceMappingURL=ngx-uploadcare-widget.js.map
